@@ -7,13 +7,12 @@ from typing import Dict, Optional, Union
 
 import click
 import mlflow
-from kedro.framework.project import pipelines
+from kedro.framework.project import pipelines, settings
 from kedro.framework.session import KedroSession
 from kedro.framework.startup import _is_project, bootstrap_project
 from mlflow.models import infer_signature
 from packaging import version
 
-from kedro_mlflow.config import get_mlflow_config
 from kedro_mlflow.framework.cli.cli_utils import write_jinja_template
 from kedro_mlflow.mlflow import KedroPipelineModel
 
@@ -88,9 +87,7 @@ def init(env: str, force: bool, silent: bool):
     mlflow_yml = "mlflow.yml"
     project_path = Path().cwd()
     project_metadata = bootstrap_project(project_path)
-    session = KedroSession.create(project_path=project_path)
-    context = session.load_context()
-    mlflow_yml_path = project_path / context.CONF_ROOT / env / mlflow_yml
+    mlflow_yml_path = project_path / settings.CONF_SOURCE / env / mlflow_yml
 
     # mlflow.yml is just a static file,
     # but the name of the experiment is set to be the same as the project
@@ -112,14 +109,14 @@ def init(env: str, force: bool, silent: bool):
         except FileNotFoundError:
             click.secho(
                 click.style(
-                    f"No env '{env}' found. Please check this folder exists inside '{context.CONF_ROOT}' folder.",
+                    f"No env '{env}' found. Please check this folder exists inside '{settings.CONF_SOURCE}' folder.",
                     fg="red",
                 )
             )
         if not silent:
             click.secho(
                 click.style(
-                    f"'{context.CONF_ROOT}/{env}/{mlflow_yml}' successfully updated.",
+                    f"'{settings.CONF_SOURCE}/{env}/{mlflow_yml}' successfully updated.",
                     fg="green",
                 )
             )
@@ -156,14 +153,14 @@ def ui(env: str, port: str, host: str):
     with KedroSession.create(
         project_path=project_path,
         env=env,
-    ):
+    ) as session:
 
-        mlflow_conf = get_mlflow_config()
-        host = host or mlflow_conf.ui.host
-        port = port or mlflow_conf.ui.port
+        context = session.load_context()
+        host = host or context.mlflow.ui.host
+        port = port or context.mlflow.ui.port
 
-        if mlflow_conf.server.mlflow_tracking_uri.startswith("http"):
-            webbrowser.open(mlflow_conf.server.mlflow_tracking_uri)
+        if context.mlflow.server.mlflow_tracking_uri.startswith("http"):
+            webbrowser.open(context.mlflow.server.mlflow_tracking_uri)
         else:
             # call mlflow ui with specific options
             # TODO : add more options for ui
@@ -172,7 +169,7 @@ def ui(env: str, port: str, host: str):
                     "mlflow",
                     "ui",
                     "--backend-store-uri",
-                    mlflow_conf.server.mlflow_tracking_uri,
+                    context.mlflow.server.mlflow_tracking_uri,
                     "--host",
                     host,
                     "--port",
@@ -304,11 +301,11 @@ def modelify(
     project_path = Path.cwd()
     bootstrap_project(project_path)
     with KedroSession.create(project_path=project_path) as session:
-        config = get_mlflow_config()
-        config.setup()
         # "pipeline" is the Pipeline object you want to convert to a mlflow model
         pipeline = pipelines[pipeline_name]
-        context = session.load_context()
+        context = (
+            session.load_context()
+        )  # triggers config setup with after_context_created hook
         catalog = context.catalog
         input_name = input_name
 
