@@ -9,10 +9,10 @@ from cookiecutter.main import cookiecutter
 from kedro import __version__ as kedro_version
 from kedro.framework.cli.cli import info
 from kedro.framework.cli.starters import TEMPLATE_PATH
+from kedro.framework.project import _ProjectSettings
 from kedro.framework.session import KedroSession
 from kedro.framework.startup import bootstrap_project
 
-from kedro_mlflow.config import get_mlflow_config
 from kedro_mlflow.config.kedro_mlflow_config import KedroMlflowConfig
 from kedro_mlflow.framework.cli.cli import init as cli_init
 from kedro_mlflow.framework.cli.cli import mlflow_commands as cli_mlflow
@@ -32,6 +32,28 @@ def extract_cmd_from_help(msg):
     return cmd_list
 
 
+@pytest.fixture(autouse=True)
+def mock_validate_settings(mocker):
+    # KedroSession eagerly validates that a project's settings.py is correct by
+    # importing it. settings.py does not actually exists as part of this test suite
+    # since we are testing session in isolation, so the validation is patched.
+    mocker.patch("kedro.framework.session.session.validate_settings")
+
+
+def _mock_imported_settings_paths(mocker, mock_settings):
+    for path in [
+        "kedro.framework.project.settings",
+        "kedro.framework.session.session.settings",
+    ]:
+        mocker.patch(path, mock_settings)
+    return mock_settings
+
+
+@pytest.fixture
+def mock_settings_fake_project(mocker):
+    return _mock_imported_settings_paths(mocker, _ProjectSettings())
+
+
 def test_cli_global_discovered(monkeypatch, tmp_path):
     monkeypatch.chdir(tmp_path)
     cli_runner = CliRunner()
@@ -78,7 +100,9 @@ def test_cli_init(monkeypatch, kedro_project):
     assert (kedro_project / "conf" / "local" / "mlflow.yml").is_file()
 
 
-def test_cli_init_existing_config(monkeypatch, kedro_project_with_mlflow_conf):
+def test_cli_init_existing_config(
+    monkeypatch, kedro_project_with_mlflow_conf, mock_settings_fake_project
+):
     # "kedro_project" is a pytest.fixture declared in conftest
     cli_runner = CliRunner()
     monkeypatch.chdir(kedro_project_with_mlflow_conf)
@@ -87,11 +111,13 @@ def test_cli_init_existing_config(monkeypatch, kedro_project_with_mlflow_conf):
     with KedroSession.create(
         "fake_project", project_path=kedro_project_with_mlflow_conf
     ) as session:
-        context = session.load_context()
         # emulate first call by writing a mlflow.yml file
         yaml_str = yaml.dump(dict(server=dict(mlflow_tracking_uri="toto")))
         (
-            kedro_project_with_mlflow_conf / context.CONF_ROOT / "local" / "mlflow.yml"
+            kedro_project_with_mlflow_conf
+            / mock_settings_fake_project.CONF_SOURCE
+            / "local"
+            / "mlflow.yml"
         ).write_text(yaml_str)
 
         result = cli_runner.invoke(cli_init)
@@ -99,24 +125,29 @@ def test_cli_init_existing_config(monkeypatch, kedro_project_with_mlflow_conf):
         # check an error message is raised
         assert "A 'mlflow.yml' already exists" in result.output
 
+        context = session.load_context()
         # check the file remains unmodified
-        assert get_mlflow_config().server.mlflow_tracking_uri.endswith("toto")
+        assert context.mlflow.server.mlflow_tracking_uri.endswith("toto")
 
 
-def test_cli_init_existing_config_force_option(monkeypatch, kedro_project):
+def test_cli_init_existing_config_force_option(
+    monkeypatch, kedro_project, mock_settings_fake_project
+):
     # "kedro_project" is a pytest.fixture declared in conftest
     monkeypatch.chdir(kedro_project)
     cli_runner = CliRunner()
 
     bootstrap_project(kedro_project)
     with KedroSession.create(project_path=kedro_project) as session:
-        context = session.load_context()
 
         # emulate first call by writing a mlflow.yml file
-        yaml_str = yaml.dump(dict(mlflow_tracking_uri="toto"))
-        (kedro_project / context.CONF_ROOT / "local" / "mlflow.yml").write_text(
-            yaml_str
-        )
+        yaml_str = yaml.dump(dict(server=dict(mlflow_tracking_uri="toto")))
+        (
+            kedro_project
+            / mock_settings_fake_project.CONF_SOURCE
+            / "local"
+            / "mlflow.yml"
+        ).write_text(yaml_str)
 
         result = cli_runner.invoke(cli_init, args="--force")
 
@@ -124,7 +155,8 @@ def test_cli_init_existing_config_force_option(monkeypatch, kedro_project):
         assert "successfully updated" in result.output
 
         # check the file remains unmodified
-        assert get_mlflow_config().server.mlflow_tracking_uri.endswith("mlruns")
+        context = session.load_context()
+        assert context.mlflow.server.mlflow_tracking_uri.endswith("mlruns")
 
 
 @pytest.mark.parametrize(
@@ -245,22 +277,31 @@ def test_ui_open_http_uri(monkeypatch, mocker, tmp_path):
     project_path = tmp_path / config["repo_name"]
     shutil.rmtree(project_path / "src" / "tests")  # avoid conflicts with pytest
 
-    kmc = KedroMlflowConfig(project_path=project_path.as_posix())
-    kmc.server.mlflow_tracking_uri = "http://google.com"
+    mlflow_config = KedroMlflowConfig(project_path=project_path.as_posix())
+    mlflow_config.server.mlflow_tracking_uri = "http://google.com"
 
     with open(
-        (kmc.project_path / "conf" / "local" / "mlflow.yml").as_posix(), "w"
+        (mlflow_config.project_path / "conf" / "local" / "mlflow.yml").as_posix(), "w"
     ) as fhandler:
         yaml.dump(
-            kmc.dict(exclude={"project_path"}), fhandler, default_flow_style=False
+            mlflow_config.dict(exclude={"project_path"}),
+            fhandler,
+            default_flow_style=False,
         )
 
     monkeypatch.chdir(project_path.as_posix())
     cli_runner = CliRunner()
 
     # This does not test anything : the goal is to check whether it raises an error
-    ui_mocker = mocker.patch(
+    # context_mocker = mocker.patch(
+    #     "kedro.framework.session.session.KedroSession.load_context"
+    # )
+    mocker.patch("kedro_mlflow.config.kedro_mlflow_config.KedroMlflowConfig.setup")
+    open_mocker = mocker.patch(
         "webbrowser.open"
     )  # make the test succeed, but no a real test
-    cli_runner.invoke(cli_ui)
-    ui_mocker.assert_called_once()
+    cli_runner.invoke(
+        cli_ui
+    )  # result=cli_runner.invoke(cli_ui); print(result.exception) to debug
+
+    open_mocker.assert_called_once()
